@@ -5,6 +5,7 @@ import (
 	"flag"
 	"fmt"
 	"strings"
+	"time"
 
 	"github.com/bougou/go-ipmi"
 	"github.com/spf13/cobra"
@@ -23,6 +24,9 @@ var (
 	privilegeLevel string
 	showVersion    bool
 
+	timeout int
+	retries int
+
 	client *ipmi.Client
 )
 
@@ -34,13 +38,25 @@ func initClient() error {
 		fmt.Printf("BuildAt: %s\n", BuildAt)
 	}
 
+	if debug {
+		fmt.Printf("host: %s\n", host)
+		fmt.Printf("port: %d\n", port)
+		fmt.Printf("username: %s\n", username)
+		fmt.Printf("password: %s\n", password)
+		fmt.Printf("intf: %s\n", intf)
+		fmt.Printf("debug: %t\n", debug)
+		fmt.Printf("showVersion: %t\n", showVersion)
+		fmt.Printf("timeout: %d\n", timeout)
+		fmt.Printf("retries: %d\n", retries)
+	}
+
 	switch intf {
 	case "", "open":
 		c, err := ipmi.NewOpenClient()
 		if err != nil {
 			return fmt.Errorf("create open client failed, err: %w", err)
 		}
-		client = c
+		client = c // assign to global variable
 		client.WithInterface(ipmi.InterfaceOpen)
 
 	case "lan", "lanplus":
@@ -48,11 +64,22 @@ func initClient() error {
 		if err != nil {
 			return fmt.Errorf("create lan or lanplus client failed, err: %w", err)
 		}
-		client = c
-		if intf == "lan" {
+		client = c // assign to global variable
+		switch intf {
+		case "lan":
 			client.WithInterface(ipmi.InterfaceLan)
-		} else if intf == "lanplus" {
+			client.WithTimeout(time.Duration(ipmi.DefaultLanTimeoutSec) * time.Second)
+			client.WithRetry(ipmi.DefaultLanRetries)
+
+		case "lanplus":
 			client.WithInterface(ipmi.InterfaceLanplus)
+			client.WithTimeout(time.Duration(ipmi.DefaultLanplusTimeoutSec) * time.Second)
+			client.WithRetry(ipmi.DefaultLanplusRetries)
+		}
+
+		client.WithRetry(retries)
+		if timeout > 0 {
+			client.WithTimeout(time.Duration(timeout) * time.Second)
 		}
 
 	case "tool":
@@ -60,8 +87,9 @@ func initClient() error {
 		if err != nil {
 			return fmt.Errorf("create client based on ipmitool (%s) failed, err: %w", host, err)
 		}
-		client = c
+		client = c // assign to global variable
 		client.WithInterface(ipmi.InterfaceTool)
+
 	default:
 		return fmt.Errorf("unsupported interface")
 	}
@@ -117,15 +145,17 @@ func NewRootCommand() *cobra.Command {
 		},
 	}
 
-	rootCmd.PersistentFlags().StringVarP(&host, "host", "H", "", "host")
-	rootCmd.PersistentFlags().IntVarP(&port, "port", "p", 623, "port")
-	rootCmd.PersistentFlags().StringVarP(&username, "user", "U", "", "username")
-	rootCmd.PersistentFlags().StringVarP(&password, "pass", "P", "", "password")
-	rootCmd.PersistentFlags().StringVarP(&intf, "interface", "I", "open", "interface, supported (open,lan,lanplus)")
-	rootCmd.PersistentFlags().BoolVarP(&debug, "debug", "d", false, "debug")
-	rootCmd.PersistentFlags().BoolVarP(&showVersion, "version", "V", false, "version")
-	rootCmd.PersistentFlags().StringVarP(&privilegeLevel, "priv-level", "L", "ADMINISTRATOR", "Force session privilege level. Can be CALLBACK, USER, OPERATOR, ADMINISTRATOR.")
-
+	rootCmd.PersistentFlags().StringVarP(&host, "host", "H", "", "Remote host name for LAN interface")
+	rootCmd.PersistentFlags().IntVarP(&port, "port", "p", 623, "Remote RMCP port")
+	rootCmd.PersistentFlags().StringVarP(&username, "user", "U", "", "Remote session username")
+	rootCmd.PersistentFlags().StringVarP(&password, "pass", "P", "", "Remote session password")
+	rootCmd.PersistentFlags().StringVarP(&intf, "interface", "I", "open", "Interface to use, supported (open,lan,lanplus)")
+	rootCmd.PersistentFlags().BoolVarP(&debug, "debug", "d", false, "Enable debug mode")
+	rootCmd.PersistentFlags().BoolVarP(&showVersion, "version", "V", false, "Show version information")
+	rootCmd.PersistentFlags().StringVarP(&privilegeLevel, "priv-level", "L", "ADMINISTRATOR", "Remote session privilege level to use. Can be CALLBACK, USER, OPERATOR, ADMINISTRATOR.")
+	rootCmd.PersistentFlags().IntVarP(&timeout, "timeout", "", 0, "timeout in seconds for each IPMI request/response cycle (not for entire command execution)"+
+		"\n0 means to use the default hard-coded timeout of the interface")
+	rootCmd.PersistentFlags().IntVarP(&retries, "retries", "R", 4, "Set the number of retries for lan/lanplus interface")
 	rootCmd.Flags().AddGoFlagSet(flag.CommandLine)
 
 	rootCmd.AddCommand(NewCmdMC())
