@@ -6,9 +6,12 @@ import (
 	"encoding/base64"
 	"encoding/binary"
 	"fmt"
+	"iter"
 	"math"
 	"math/rand"
+	"os"
 	"strconv"
+	"strings"
 	"time"
 
 	"github.com/kr/pretty"
@@ -43,11 +46,11 @@ func debugBytes(header string, data []byte, width int) {
 }
 
 // debugf pretty print any object
-func debugf(format string, object ...interface{}) {
+func debugf(format string, object ...any) {
 	pretty.Printf(format, object...)
 }
 
-func debug(header string, object interface{}) {
+func debug(header string, object any) {
 	if header == "" {
 		pretty.Printf("%# v\n", object)
 	} else {
@@ -55,14 +58,14 @@ func debug(header string, object interface{}) {
 	}
 }
 
-func (c *Client) Debugf(format string, object ...interface{}) {
+func (c *Client) Debugf(format string, object ...any) {
 	if !c.debug {
 		return
 	}
 	debugf(format, object...)
 }
 
-func (c *Client) Debug(header string, object interface{}) {
+func (c *Client) Debug(header string, object any) {
 	if !c.debug {
 		return
 	}
@@ -77,7 +80,7 @@ func (c *Client) DebugBytes(header string, data []byte, width int) {
 	debugBytes(header, data, width)
 }
 
-func (c *Client) DebugfRed(format string, object ...interface{}) {
+func (c *Client) DebugfRed(format string, object ...any) {
 	if !c.debug {
 		return
 	}
@@ -85,7 +88,7 @@ func (c *Client) DebugfRed(format string, object ...interface{}) {
 	fmt.Printf(colorRed+format+"\033[0m", object...)
 }
 
-func (c *Client) DebugfGreen(format string, object ...interface{}) {
+func (c *Client) DebugfGreen(format string, object ...any) {
 	if !c.debug {
 		return
 	}
@@ -93,7 +96,7 @@ func (c *Client) DebugfGreen(format string, object ...interface{}) {
 	fmt.Printf(colorGreen+format+"\033[0m", object...)
 }
 
-func (c *Client) DebugfYellow(format string, object ...interface{}) {
+func (c *Client) DebugfYellow(format string, object ...any) {
 	if !c.debug {
 		return
 	}
@@ -658,6 +661,7 @@ func parseStringToInt64(s string) (int64, error) {
 }
 
 // RenderTable formats a table from a slice of rows.
+// The Headers is a slice of strings, the order of the headers is the order of the columns in the table.
 // Each row is represented as a map, the keys of the map are the headers of the table.
 func RenderTable(headers []string, rows []map[string]string) string {
 	var buf = new(bytes.Buffer)
@@ -679,7 +683,7 @@ func RenderTable(headers []string, rows []map[string]string) string {
 
 	// Add rows
 	for _, _row := range rows {
-		row := make([]interface{}, len(headers))
+		row := make([]any, len(headers))
 		for i, header := range headers {
 			row[i] = _row[header]
 		}
@@ -690,6 +694,84 @@ func RenderTable(headers []string, rows []map[string]string) string {
 	return buf.String()
 }
 
+func RenderTableStream(headers []string, rowSeq iter.Seq[map[string]string]) error {
+	table := tablewriter.NewTable(os.Stdout, tablewriter.WithStreaming(tw.StreamConfig{Enable: true}))
+
+	table.Options(
+		tablewriter.WithRenderer(renderer.NewBlueprint(tw.Rendition{Symbols: tw.NewSymbols(tw.StyleASCII)})),
+		tablewriter.WithRowAlignment(tw.AlignRight),
+		tablewriter.WithRowAutoWrap(0), // Disable auto wrap
+		tablewriter.WithFooterAlignmentConfig(tw.CellAlignment{
+			Global: tw.AlignCenter, // Center align footer like header
+		}),
+		tablewriter.WithFooterAutoFormat(tw.On),
+	)
+
+	// Start streaming
+	if err := table.Start(); err != nil {
+		return fmt.Errorf("table start failed: %w", err)
+	}
+	defer table.Close()
+
+	table.Header(headers)
+
+	for _row := range rowSeq {
+		row := make([]any, len(headers))
+		for i, header := range headers {
+			canonicalHeader := strings.TrimSpace(header)
+			canonicalHeader = strings.Trim(canonicalHeader, "-")
+			canonicalHeader = strings.TrimSpace(canonicalHeader)
+			row[i] = _row[canonicalHeader]
+		}
+		table.Append(row)
+	}
+
+	table.Footer(headers)
+
+	return nil
+
+}
+
+type itemToRowFn[T any] func(item *T, options ...any) map[string]string
+
+func formatStream[T any](seq iter.Seq[*Result[T]], headers []string, itemToRowFn itemToRowFn[T], itemToRowFnOptions ...any) error {
+	var resultErr error
+
+	// convert channel to sequence.
+	rowSeq := func(seq iter.Seq[*Result[T]]) iter.Seq[map[string]string] {
+		return func(yield func(map[string]string) bool) {
+			for result := range seq {
+				if result == nil {
+					continue
+				}
+
+				if result.Err != nil {
+					resultErr = result.Err
+					return
+				}
+
+				item := result.Ok
+				if item != nil {
+					row := itemToRowFn(item, itemToRowFnOptions...)
+					if !yield(row) {
+						return
+					}
+				}
+			}
+		}
+	}
+
+	if err := RenderTableStream(headers, rowSeq(seq)); err != nil {
+		return fmt.Errorf("render table stream failed, err: %w", resultErr)
+	}
+
+	if resultErr != nil {
+		return fmt.Errorf("got result error, err: %w", resultErr)
+	}
+
+	return nil
+}
+
 // buildCanIgnoreFn returns a `canIgnore` function that can be used to check if a err
 // is a ResponseError with CompletionCode in specified codes.
 // If so, the `canIgnore` function returns nil, otherwise it returns the original err.
@@ -719,9 +801,9 @@ func isErrOfCompletionCodes(err error, codes ...uint8) bool {
 	return false
 }
 
-// Generic function to convert a slice of any type to a slice of interface{}
-func convertToInterfaceSlice[T any](input []T) []interface{} {
-	result := make([]interface{}, len(input))
+// Generic function to convert a slice of any type to a slice of any
+func convertToInterfaceSlice[T any](input []T) []any {
+	result := make([]any, len(input))
 	for i, v := range input {
 		result[i] = v
 	}
